package
module
Version:
v0.0.11
Opens a new window with list of versions in this module.
Published: May 28, 2019
License: MIT
Opens a new window with license information.
Imports: 10
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
Documentation
¶
Name returns a name for the logger.
It returns the empty string if the code is unknown.
type Config struct {
Loggers Map
TimeFormat string
IgnoreFileLine bool
}
Config contains settings and registered loggers
Log logger himself
Method for recording errors without stack
ErrorDebug method for recording errors with stack
GetLoggerInterfaceByType returns io.Writer interface for logging in third-party libraries
Info method for recording informational messages
Infof method of recording formatted informational messages
Warning method for recording warning messages
Logger logger structure which includes a channel and a slice strategies
Writer interface for informational messages
Map mapping for type:logger
Writer interface for loggers
Create creates an instance of the logger
Default created standart logger. Writes to stdout and stderr
Source Files
¶
Directories
¶
Package mocks is a generated GoMock package.
|
Package mocks is a generated GoMock package. |
strategy
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Click to show internal directories.
Click to hide internal directories.